scxpand.util.train\_logger
==========================

.. automodule:: scxpand.util.train_logger

   
   .. rubric:: Functions

   .. autosummary::
   
      has_checkpoint
   
   .. rubric:: Classes

   .. autosummary::
   
      TrainLogger
   